MCD inheritance
ALIQUET ( #magna, #tellus )

- Le champ magna fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité TRISTIS.
- Le champ tellus fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité DIGNISSIM.

CONSEQUAT ( fermentum, dederit )

- Le champ fermentum constitue la clé primaire de la table. C'était déjà un identifiant de l'entité CONSEQUAT.
- Le champ dederit était déjà un simple attribut de l'entité CONSEQUAT.

CURABITUR ( gravida, amor )

- Le champ gravida constitue la clé primaire de la table. C'était déjà un identifiant de l'entité CURABITUR.
- Le champ amor était déjà un simple attribut de l'entité CURABITUR.

DIGNISSIM ( tellus, terra )

- Le champ tellus constitue la clé primaire de la table. C'était déjà un identifiant de l'entité DIGNISSIM.
- Le champ terra était déjà un simple attribut de l'entité DIGNISSIM.

LIBERO ( posuere, lacrima )

- Le champ posuere constitue la clé primaire de la table. C'était déjà un identifiant de l'entité LIBERO.
- Le champ lacrima était déjà un simple attribut de l'entité LIBERO.

QUAM ( cras, sed, #magna! )

- Le champ cras constitue la clé primaire de la table. C'était déjà un identifiant de l'entité QUAM.
- Le champ sed était déjà un simple attribut de l'entité QUAM.
- Le champ à saisie obligatoire magna est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle VITAE à partir de l'entité TRISTIS en perdant son caractère identifiant.

SUSCIPIT ( orci, lorem, #magna! )

- Le champ orci constitue la clé primaire de la table. C'était déjà un identifiant de l'entité SUSCIPIT.
- Le champ lorem était déjà un simple attribut de l'entité SUSCIPIT.
- Le champ à saisie obligatoire magna est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle RHONCUS à partir de l'entité TRISTIS en perdant son caractère identifiant.

TRISTIS ( magna, vestibulum, #fermentum!, type!, convallis?, ipsum?, pulvinar?, audis?, #gravida?, tempor?, fugit? )

- Le champ magna constitue la clé primaire de la table. C'était déjà un identifiant de l'entité TRISTIS.
- Le champ vestibulum était déjà un simple attribut de l'entité TRISTIS.
- Le champ à saisie obligatoire fermentum est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle ELIT à partir de l'entité CONSEQUAT en perdant son caractère identifiant.
- Un discriminateur à saisie obligatoire type est ajouté pour indiquer la nature de la spécialisation. Jamais vide, du fait de la contrainte de totalité.
- Le champ à saisie facultative convallis a migré à partir de l'entité-fille SODALES (supprimée).
- Le champ à saisie facultative ipsum a migré à partir de l'entité-fille SODALES (supprimée).
- Le champ à saisie facultative pulvinar a migré à partir de l'entité-fille NEC (supprimée).
- Le champ à saisie facultative audis a migré à partir de l'entité-fille NEC (supprimée).
- Le champ à saisie facultative gravida est une clé étrangère. Il a migré à partir de l'entité-fille NEC (supprimée) dans laquelle il avait déjà migré à partir de l'entité CURABITUR.
- Le champ à saisie facultative tempor a migré à partir de l'entité-fille LACUS (supprimée).
- Le champ à saisie facultative fugit a migré à partir de l'entité-fille LACUS (supprimée).

ULTRICES ( #posuere, #magna )

- Le champ posuere fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité LIBERO.
- Le champ magna fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité TRISTIS.